@@ -32,8 +32,9 @@ export default class TagsUtils {
             if(index == i) {
                 continue;
             }
-            const cellTag: string = CellUtils.getCellMetaData(notebookPanel.content, index, 'transformer') || null;
+            const cellTag: string = CellUtils.getCellMetaData(notebookPanel.content, i, 'transformer') || null;
             if (tag === cellTag) {
+                console.log("Duplicate with " + index + " and " + i);
                 return true;
             }
         }
