@@ -72,7 +72,6 @@ const makeCellTransformerWidgets = (notebookPanel: NotebookPanel) => {
         if (! isCodeCell) {
             continue;
         }
-        console.log(cells.get(index).id);
         let transformerTag: string = TagsUtils.getCellTransformerTag(notebookPanel, index)? TagsUtils.getCellTransformerTag(notebookPanel, index) : null;
 
         let cellElement: HTMLElement = notebookPanel.content.node.childNodes[index] as HTMLElement;
@@ -87,7 +86,6 @@ const makeCellTransformerWidgets = (notebookPanel: NotebookPanel) => {
 }
 
 const createCellTransformerWidgets = (cellId: string, notebookPanel: NotebookPanel, cellElement: HTMLElement, transformerTag: string, isTransformerEnabled: boolean) => {
-    console.log("createCellTransformerWidgets...");
     const newChildNode = document.createElement('div')
     newChildNode.className = "cell-transformer-widget";
     let oldWidgets = cellElement.getElementsByClassName("cell-transformer-widget");
