@@ -1,7 +1,6 @@
 import * as React from 'react';
 import { ThemeProvider } from '@material-ui/core/styles';
 import { theme } from './../theme';
-import { Button } from '@material-ui/core';
 import { executeRpc, globalUnhandledRejection } from './../lib/RPCUtils';
 import NotebookUtils from './../lib/NotebookUtils';
 import { Kernel } from '@jupyterlab/services';
@@ -9,6 +8,7 @@ import { Switch } from '@material-ui/core';
 import { ISettingRegistry } from '@jupyterlab/settingregistry';
 import { getTransformerEnabled, setTransformerEnabled } from './../settings';
 import { getTransformerNotebookDirectory } from './../notebook';
+import { Button, Dialog, DialogActions, DialogContent, DialogTitle } from '@material-ui/core';
 
 interface IProps {
     transformerSettings: ISettingRegistry.ISettings
@@ -16,15 +16,28 @@ interface IProps {
 
 interface IState {
     isEnabled: boolean;
+    dialogTitle: string;
+    dialogContent: string;
+    isDialogVisible: boolean;
+    isDialogButtonVisible: boolean;
 }
 
 export class TransformerLeftPanel extends React.Component<IProps, IState> {
     constructor(props: IProps) {
         super(props);
         const defaultState: IState = {
-            isEnabled: getTransformerEnabled(this.props.transformerSettings)
+            isEnabled: getTransformerEnabled(this.props.transformerSettings),
+            isDialogVisible: false,
+            isDialogButtonVisible: true,
+            dialogTitle: '',
+            dialogContent: ''
         };
         this.state = defaultState;
+        this.onDialogCloseClick = this.onDialogCloseClick.bind(this);
+    }
+
+    onDialogCloseClick() {
+        this.setState({ isDialogVisible: !this.state.isDialogVisible });
     }
 
     componentDidMount = () => {
@@ -41,6 +54,12 @@ export class TransformerLeftPanel extends React.Component<IProps, IState> {
 
     applyTransformerToProxy = async () => {
         console.log('applyTransformerToProxy');
+        this.setState({
+            isDialogVisible: true,
+            isDialogButtonVisible: false,
+            dialogTitle: 'Running',
+            dialogContent: 'It will take few seconds!'
+        });
 
         try {
             const kernel: Kernel.IKernelConnection = await NotebookUtils.createNewKernel();
@@ -50,6 +69,12 @@ export class TransformerLeftPanel extends React.Component<IProps, IState> {
             }
             const result = await executeRpc(kernel, 'nb.parse_notebook', args);
             console.log(result);
+            this.setState({
+                isDialogVisible: true,
+                isDialogButtonVisible: true,
+                dialogTitle: 'Done',
+                dialogContent: 'The transforming is completed!'
+            });
         } catch (error) {
             globalUnhandledRejection({ reason: error });
             throw error;
@@ -113,6 +138,28 @@ export class TransformerLeftPanel extends React.Component<IProps, IState> {
                         </div>
                     </div>
                 </div>
+                <Dialog
+                    open={this.state.isDialogVisible}
+                    fullWidth={true}
+                    maxWidth={'sm'}
+                    scroll="paper"
+                    aria-labelledby="scroll-dialog-title"
+                    aria-describedby="scroll-dialog-description"
+                >
+                    <DialogTitle id="scroll-dialog-title">
+                        <p className={'dialog-title'} >{this.state.dialogTitle}</p>
+                    </DialogTitle>
+                    <DialogContent dividers={true}>
+                        <p>{this.state.dialogContent}</p>
+                    </DialogContent>
+                    <DialogActions>
+                        <Button
+                            className={ 'transformer-dialog ' + (this.state.isDialogButtonVisible ? '' : 'hidden') }
+                            color="primary"
+                            onClick={this.onDialogCloseClick}
+                        >Ok</Button>
+                    </DialogActions>
+                </Dialog>
             </ThemeProvider>
         );
     }
